<?php

namespace Litecms\Subcriber\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Subcriber\Models\Subscribe;

class SubscribePolicy
{

    /**
     * Determine if the given user can view the subscribe.
     *
     * @param UserPolicy $user
     * @param Subscribe $subscribe
     *
     * @return bool
     */
    public function view(UserPolicy $user, Subscribe $subscribe)
    {
        if ($user->canDo('subcriber.subscribe.view') && $user->isAdmin()) {
            return true;
        }

        return $subscribe->user_id == user_id() && $subscribe->user_type == user_type();
    }

    /**
     * Determine if the given user can create a subscribe.
     *
     * @param UserPolicy $user
     * @param Subscribe $subscribe
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('subcriber.subscribe.create');
    }

    /**
     * Determine if the given user can update the given subscribe.
     *
     * @param UserPolicy $user
     * @param Subscribe $subscribe
     *
     * @return bool
     */
    public function update(UserPolicy $user, Subscribe $subscribe)
    {
        if ($user->canDo('subcriber.subscribe.edit') && $user->isAdmin()) {
            return true;
        }

        return $subscribe->user_id == user_id() && $subscribe->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given subscribe.
     *
     * @param UserPolicy $user
     * @param Subscribe $subscribe
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Subscribe $subscribe)
    {
        return $subscribe->user_id == user_id() && $subscribe->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given subscribe.
     *
     * @param UserPolicy $user
     * @param Subscribe $subscribe
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Subscribe $subscribe)
    {
        if ($user->canDo('subcriber.subscribe.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given subscribe.
     *
     * @param UserPolicy $user
     * @param Subscribe $subscribe
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Subscribe $subscribe)
    {
        if ($user->canDo('subcriber.subscribe.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
